From: Slawomir Mrozowicz <slawomirx.mrozow...@intel.com>

Device id is going to be removed from session,
as the session will be device independent.
Therefore, the functions that attach/dettach a session
to a queue pair need to be updated, to accept the device id
as a parameter, apart from the queue pair id and the session.

Signed-off-by: Slawomir Mrozowicz <slawomirx.mrozow...@intel.com>
Signed-off-by: Pablo de Lara <pablo.de.lara.gua...@intel.com>
---
 doc/guides/rel_notes/release_17_08.rst |  3 +++
 examples/ipsec-secgw/ipsec.c           |  1 +
 lib/librte_cryptodev/rte_cryptodev.c   | 20 ++++++++++----------
 lib/librte_cryptodev/rte_cryptodev.h   | 10 ++++++----
 4 files changed, 20 insertions(+), 14 deletions(-)

diff --git a/doc/guides/rel_notes/release_17_08.rst 
b/doc/guides/rel_notes/release_17_08.rst
index 06c5e4e..9b0b4d4 100644
--- a/doc/guides/rel_notes/release_17_08.rst
+++ b/doc/guides/rel_notes/release_17_08.rst
@@ -205,6 +205,9 @@ API Changes
   * ``rte_cryptodev_configure()`` does not create the session mempool
     for the device anymore.
   * Removed ``session_mp`` from ``rte_cryptodev_config``.
+  * ``rte_cryptodev_queue_pair_attach_sym_session()`` and
+    ``rte_cryptodev_queue_pair_dettach_sym_session()`` functions require
+    the new parameter ``device id``.
 
 
 ABI Changes
diff --git a/examples/ipsec-secgw/ipsec.c b/examples/ipsec-secgw/ipsec.c
index ecfd4e8..f09dce9 100644
--- a/examples/ipsec-secgw/ipsec.c
+++ b/examples/ipsec-secgw/ipsec.c
@@ -77,6 +77,7 @@ create_session(struct ipsec_ctx *ipsec_ctx __rte_unused, 
struct ipsec_sa *sa)
        rte_cryptodev_info_get(ipsec_ctx->tbl[cdev_id_qp].id, &cdev_info);
        if (cdev_info.sym.max_nb_sessions_per_qp > 0) {
                ret = rte_cryptodev_queue_pair_attach_sym_session(
+                               ipsec_ctx->tbl[cdev_id_qp].id,
                                ipsec_ctx->tbl[cdev_id_qp].qp,
                                sa->crypto_session);
                if (ret < 0) {
diff --git a/lib/librte_cryptodev/rte_cryptodev.c 
b/lib/librte_cryptodev/rte_cryptodev.c
index 0778d5f..078e26b 100644
--- a/lib/librte_cryptodev/rte_cryptodev.c
+++ b/lib/librte_cryptodev/rte_cryptodev.c
@@ -1136,23 +1136,23 @@ rte_cryptodev_sym_session_create(uint8_t dev_id,
 }
 
 int
-rte_cryptodev_queue_pair_attach_sym_session(uint16_t qp_id,
+rte_cryptodev_queue_pair_attach_sym_session(uint8_t dev_id, uint16_t qp_id,
                struct rte_cryptodev_sym_session *sess)
 {
        struct rte_cryptodev *dev;
 
-       if (!rte_cryptodev_pmd_is_valid_dev(sess->dev_id)) {
-               CDEV_LOG_ERR("Invalid dev_id=%d", sess->dev_id);
+       if (!rte_cryptodev_pmd_is_valid_dev(dev_id)) {
+               CDEV_LOG_ERR("Invalid dev_id=%d", dev_id);
                return -EINVAL;
        }
 
-       dev = &rte_crypto_devices[sess->dev_id];
+       dev = &rte_crypto_devices[dev_id];
 
        /* The API is optional, not returning error if driver do not suuport */
        RTE_FUNC_PTR_OR_ERR_RET(*dev->dev_ops->qp_attach_session, 0);
        if (dev->dev_ops->qp_attach_session(dev, qp_id, sess->_private)) {
                CDEV_LOG_ERR("dev_id %d failed to attach qp: %d with session",
-                               sess->dev_id, qp_id);
+                               dev_id, qp_id);
                return -EPERM;
        }
 
@@ -1160,23 +1160,23 @@ rte_cryptodev_queue_pair_attach_sym_session(uint16_t 
qp_id,
 }
 
 int
-rte_cryptodev_queue_pair_detach_sym_session(uint16_t qp_id,
+rte_cryptodev_queue_pair_detach_sym_session(uint8_t dev_id, uint16_t qp_id,
                struct rte_cryptodev_sym_session *sess)
 {
        struct rte_cryptodev *dev;
 
-       if (!rte_cryptodev_pmd_is_valid_dev(sess->dev_id)) {
-               CDEV_LOG_ERR("Invalid dev_id=%d", sess->dev_id);
+       if (!rte_cryptodev_pmd_is_valid_dev(dev_id)) {
+               CDEV_LOG_ERR("Invalid dev_id=%d", dev_id);
                return -EINVAL;
        }
 
-       dev = &rte_crypto_devices[sess->dev_id];
+       dev = &rte_crypto_devices[dev_id];
 
        /* The API is optional, not returning error if driver do not suuport */
        RTE_FUNC_PTR_OR_ERR_RET(*dev->dev_ops->qp_detach_session, 0);
        if (dev->dev_ops->qp_detach_session(dev, qp_id, sess->_private)) {
                CDEV_LOG_ERR("dev_id %d failed to detach qp: %d from session",
-                               sess->dev_id, qp_id);
+                               dev_id, qp_id);
                return -EPERM;
        }
 
diff --git a/lib/librte_cryptodev/rte_cryptodev.h 
b/lib/librte_cryptodev/rte_cryptodev.h
index 33842f9..0ade05e 100644
--- a/lib/librte_cryptodev/rte_cryptodev.h
+++ b/lib/librte_cryptodev/rte_cryptodev.h
@@ -953,7 +953,8 @@ rte_cryptodev_get_private_session_size(uint8_t dev_id);
 /**
  * Attach queue pair with sym session.
  *
  * @param      qp_id           Queue pair to which session will be attached.
attached.
  * @param      session         Session pointer previously allocated by
  *                             *rte_cryptodev_sym_session_create*.
  *
@@ -962,13 +963,14 @@ rte_cryptodev_get_private_session_size(uint8_t dev_id);
  *  - On failure, a negative value.
  */
 int
-rte_cryptodev_queue_pair_attach_sym_session(uint16_t qp_id,
+rte_cryptodev_queue_pair_attach_sym_session(uint8_t dev_id, uint16_t qp_id,
                struct rte_cryptodev_sym_session *session);
 
 /**
  * Detach queue pair with sym session.
  *
  * @param      qp_id           Queue pair to which session is attached.
  * @param      session         Session pointer previously allocated by
  *                             *rte_cryptodev_sym_session_create*.
  *
@@ -977,7 +979,7 @@ rte_cryptodev_queue_pair_attach_sym_session(uint16_t qp_id,
  *  - On failure, a negative value.
  */
 int
-rte_cryptodev_queue_pair_detach_sym_session(uint16_t qp_id,
+rte_cryptodev_queue_pair_detach_sym_session(uint8_t dev_id, uint16_t qp_id,
                struct rte_cryptodev_sym_session *session);
 
 /**
@@ -953,7 +953,8 @@ rte_cryptodev_get_private_session_size(uint8_t dev_id);
  * Attach queue pair with sym session.
  *
- * @param      qp_id           Queue pair to which session will be attached.
+ * @param      dev_id          Device to which the session will be attached.
+ * @param      qp_id           Queue pair to which the session will be 
attached.
  * @param      session         Session pointer previously allocated by
@@ -962,13 +963,14 @@ rte_cryptodev_get_private_session_size(uint8_t dev_id);
  * Detach queue pair with sym session.
  *
- * @param      qp_id           Queue pair to which session is attached.
+ * @param      dev_id          Device to which the session is attached.
+ * @param      qp_id           Queue pair to which the session is attached.
  * @param      session         Session pointer previously allocated by
  *                             *rte_cryptodev_sym_session_create*.
-- 
2.9.4

Reply via email to